@@ -1,6 +1,5 @@
 from dataclasses import dataclass
-from typing import TYPE_CHECKING
-
+from typing import TYPE_CHECKING, Any, Dict, Optional
 
 if TYPE_CHECKING:
     from strawberry.channels.handlers.base import ChannelsConsumer
@@ -13,6 +12,7 @@ class StrawberryChannelsContext:
     """
 
     request: "ChannelsConsumer"
+    connection_params: Optional[Dict[str, Any]] = None
 
     @property
     def ws(self):
