@@ -41,6 +41,7 @@ def field(
     default: Any = UNSET,
     default_factory: Union[Callable[..., object], object] = UNSET,
     directives: Sequence[object] = (),
+    graphql_type: Optional[Any] = None,
 ) -> T:
     ...
 
@@ -64,6 +65,7 @@ def field(
     default: Any = UNSET,
     default_factory: Union[Callable[..., object], object] = UNSET,
     directives: Sequence[object] = (),
+    graphql_type: Optional[Any] = None,
 ) -> Any:
     ...
 
@@ -87,6 +89,7 @@ def field(
     default: Any = UNSET,
     default_factory: Union[Callable[..., object], object] = UNSET,
     directives: Sequence[object] = (),
+    graphql_type: Optional[Any] = None,
 ) -> StrawberryField:
     ...
 
@@ -109,6 +112,7 @@ def field(
     default: Any = dataclasses.MISSING,
     default_factory: Union[Callable[..., object], object] = dataclasses.MISSING,
     directives: Sequence[object] = (),
+    graphql_type: Optional[Any] = None,
     # This init parameter is used by PyRight to determine whether this field
     # is added in the constructor or not. It is not used to change
     # any behavior at the moment.
@@ -158,4 +162,5 @@ def field(
         default_factory=default_factory,
         init=init,  # type: ignore
         directives=directives,
+        graphql_type=graphql_type,
     )
